@@ -1,3 +1,13 @@
+/* 
+   This file is public domain.
+
+   The data is a matter of public record, and comes from
+   http://unstats.un.org/   
+ */
+
+
+SET search_path TO sqltutor;
+
 INSERT INTO national_capitals (country, city) VALUES ('AFG', 'Kabul');
 INSERT INTO national_capitals (country, city) VALUES ('ALA', 'Mariehamn');
 INSERT INTO national_capitals (country, city) VALUES ('ALB', 'Tirana');
