@@ -1,11 +1,20 @@
--- http://unstats.un.org/unsd/methods/m49/m49regin.htm
--- 2008-10-04
---
--- Composition of macro geographical (continental) regions, geographical
--- sub-regions, and selected economic and other groupings
+/* 
+   This file is public domain.
+
+   The data is a matter of public record, and comes from
+   http://unstats.un.org/unsd/methods/m49/m49regin.htm
+
+   2008-10-04
+   
+   Composition of macro geographical (continental) regions, geographical
+   sub-regions, and selected economic and other groupings
+ */
+
 
 /* Geographical region and composition */
 
+SET search_path TO sqltutor;
+
 INSERT INTO un_regions VALUES (001, 'World');
 INSERT INTO un_regions VALUES (002, 'Africa');
 INSERT INTO un_regions VALUES (014, 'Eastern Africa');
